@@ -19,11 +19,6 @@ struct TreeSitterParser {
 
 impl TreeSitterParser {
     fn build(&self) {
-        // In rustc 1.61+, we need to specify +whole-archive.
-        // See https://github.com/rust-lang/rust/blob/1.61.0/RELEASES.md#compatibility-notes
-        // and https://github.com/Wilfred/difftastic/issues/339.
-        let rustc_supports_whole_archive = !rustc::is_max_version("1.60.0").unwrap_or(false);
-
         let dir = PathBuf::from(&self.src_dir);
 
         let mut c_files = vec!["parser.c"];
@@ -54,16 +49,13 @@ impl TreeSitterParser {
                 .flag_if_supported("-Wno-unused-but-set-variable")
                 // Workaround for: https://github.com/ganezdragon/tree-sitter-perl/issues/16
                 // should be removed after fixed.
-                .flag_if_supported("-Wno-return-type");
+                .flag_if_supported("-Wno-return-type")
+                .link_lib_modifier("+whole-archive");
 
             for file in cpp_files {
                 cpp_build.file(dir.join(file));
             }
 
-            if rustc_supports_whole_archive {
-                cpp_build.link_lib_modifier("+whole-archive");
-            }
-
             cpp_build.compile(&format!("{}-cpp", self.name));
         }
 
@@ -76,9 +68,7 @@ impl TreeSitterParser {
             build.file(dir.join(file));
         }
 
-        if rustc_supports_whole_archive {
-            build.link_lib_modifier("+whole-archive");
-        }
+        build.link_lib_modifier("+whole-archive");
 
         build.compile(self.name);
     }
@@ -321,6 +311,11 @@ fn main() {
             src_dir: "vendored_parsers/tree-sitter-sql-src",
             extra_files: vec!["scanner.cc"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-sfapex",
+            src_dir: "vendored_parsers/tree-sitter-sfapex-src",
+            extra_files: vec![],
+        },
         TreeSitterParser {
             name: "tree-sitter-swift",
             src_dir: "vendored_parsers/tree-sitter-swift-src",
@@ -370,6 +365,10 @@ fn main() {
 
     parsers.par_iter().for_each(|p| p.build());
     commit_info();
+
+    if let Some((version, _, _)) = rustc::triple() {
+        println!("cargo:rustc-env=DFT_RUSTC_VERSION={}", version);
+    }
 }
 
 fn commit_info() {
