@@ -23,7 +23,7 @@ pub(crate) const DEFAULT_PARSE_ERROR_LIMIT: usize = 0;
 
 pub(crate) const DEFAULT_TAB_WIDTH: usize = 8;
 
-const USAGE: &str = concat!(env!("CARGO_BIN_NAME"), " [OPTIONS] OLD-PATH NEW-PATH");
+pub(crate) const USAGE: &str = concat!(env!("CARGO_BIN_NAME"), " [OPTIONS] OLD-PATH NEW-PATH");
 
 #[derive(Debug, Clone, Copy)]
 pub(crate) enum ColorOutput {
@@ -376,8 +376,8 @@ pub(crate) enum Mode {
         rhs_path: FileArgument,
         /// The path that we show to the user.
         display_path: String,
-        /// If this file has been renamed, the name it had previously.
-        old_path: Option<String>,
+        /// If this file has been renamed, a description of the change.
+        renamed: Option<String>,
     },
     DiffFromConflicts {
         diff_options: DiffOptions,
@@ -449,7 +449,7 @@ fn build_display_path(lhs_path: &FileArgument, rhs_path: &FileArgument) -> Strin
 }
 
 fn parse_overrides_or_die(raw_overrides: &[String]) -> Vec<(LanguageOverride, Vec<glob::Pattern>)> {
-    let mut res: Vec<(LanguageOverride, Vec<glob::Pattern>)> = vec![];
+    let mut overrides: Vec<(LanguageOverride, Vec<glob::Pattern>)> = vec![];
     let mut invalid_syntax = false;
 
     for raw_override in raw_overrides {
@@ -457,7 +457,7 @@ fn parse_overrides_or_die(raw_overrides: &[String]) -> Vec<(LanguageOverride, Ve
             match glob::Pattern::new(glob_str) {
                 Ok(pattern) => {
                     if let Some(language_override) = language_override_from_name(lang_name) {
-                        res.push((language_override, vec![pattern]));
+                        overrides.push((language_override, vec![pattern]));
                     } else {
                         eprintln!("No such language '{}'", lang_name);
                         eprintln!("See --list-languages for the names of all languages available. Language overrides are case insensitive.");
@@ -481,7 +481,8 @@ fn parse_overrides_or_die(raw_overrides: &[String]) -> Vec<(LanguageOverride, Ve
         std::process::exit(EXIT_BAD_ARGUMENTS);
     }
 
-    res.into_iter()
+    overrides
+        .into_iter()
         .coalesce(
             |(prev_lang, mut prev_globs), (current_lang, current_globs)| {
                 if prev_lang == current_lang {
@@ -634,7 +635,7 @@ pub(crate) fn parse_args() -> Mode {
     info!("CLI arguments: {:?}", args);
 
     // TODO: document these different ways of calling difftastic.
-    let (display_path, lhs_path, rhs_path, old_path) = match &args[..] {
+    let (display_path, lhs_path, rhs_path, renamed) = match &args[..] {
         [lhs_path, rhs_path] => {
             let lhs_arg = FileArgument::from_cli_argument(lhs_path);
             let rhs_arg = FileArgument::from_cli_argument(rhs_path);
@@ -724,7 +725,7 @@ pub(crate) fn parse_args() -> Mode {
         lhs_path,
         rhs_path,
         display_path,
-        old_path,
+        renamed,
     }
 }
 
