@@ -19,6 +19,7 @@ use strum::{EnumIter, IntoEnumIterator};
 #[derive(Debug, Clone, Copy, PartialEq, Eq, EnumIter)]
 pub(crate) enum Language {
     Ada,
+    Apex,
     Bash,
     C,
     Clojure,
@@ -105,6 +106,7 @@ pub(crate) fn language_override_from_name(name: &str) -> Option<LanguageOverride
 pub(crate) fn language_name(language: Language) -> &'static str {
     match language {
         Ada => "Ada",
+        Apex => "Apex",
         Bash => "Bash",
         C => "C",
         Clojure => "Clojure",
@@ -217,6 +219,7 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
             "zshenv",
             "zshrc",
         ],
+        Apex => &["*.cls", "*.apexc", "*.trigger"],
         C => &["*.c"],
         Clojure => &[
             "*.bb", "*.boot", "*.clj", "*.cljc", "*.clje", "*.cljs", "*.cljx", "*.edn", "*.joke",
@@ -356,6 +359,7 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
             "*.vbproj",
             "*.xaml",
             "*.xml",
+            "*.xsd",
             "*.xsl",
             "*.xslt",
             "App.config",
