@@ -61,6 +61,7 @@ pub(crate) struct TreeSitterConfig {
 
 extern "C" {
     fn tree_sitter_ada() -> ts::Language;
+    fn tree_sitter_apex() -> ts::Language;
     fn tree_sitter_bash() -> ts::Language;
     fn tree_sitter_c() -> ts::Language;
     fn tree_sitter_c_sharp() -> ts::Language;
@@ -146,6 +147,30 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
+        Apex => {
+            let language = unsafe { tree_sitter_apex() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec![
+                    "string_literal",
+                    "null_literal",
+                    "boolean",
+                    "int",
+                    "decimal_floating_point_literal",
+                    "date_literal",
+                    "currency_literal",
+                ]
+                .into_iter()
+                .collect(),
+                delimiter_tokens: vec![("[", "]"), ("(", ")"), ("{", "}")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendored_parsers/highlights/apex.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         Bash => {
             let language = unsafe { tree_sitter_bash() };
             TreeSitterConfig {
@@ -199,7 +224,7 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_clojure() };
             TreeSitterConfig {
                 language,
-                atom_nodes: vec!["kwd_lit"].into_iter().collect(),
+                atom_nodes: vec!["kwd_lit", "regex_lit"].into_iter().collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")]
                     .into_iter()
                     .collect(),
@@ -428,8 +453,11 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 language,
                 atom_nodes: vec![
                     "qualified_variable",
+                    // Work around https://github.com/tree-sitter/tree-sitter-haskell/issues/102
                     "qualified_module",
                     "qualified_constructor",
+                    // Work around https://github.com/tree-sitter/tree-sitter-haskell/issues/107
+                    "strict_type",
                 ]
                 .into_iter()
                 .collect(),
@@ -1455,10 +1483,10 @@ fn all_syntaxes_from_cursor<'a>(
     subtrees: &DftHashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)>,
     ignore_comments: bool,
 ) -> Vec<&'a Syntax<'a>> {
-    let mut result: Vec<&Syntax> = vec![];
+    let mut nodes: Vec<&Syntax> = vec![];
 
     loop {
-        result.extend(syntax_from_cursor(
+        nodes.extend(syntax_from_cursor(
             arena,
             src,
             nl_pos,
@@ -1475,7 +1503,7 @@ fn all_syntaxes_from_cursor<'a>(
         }
     }
 
-    result
+    nodes
 }
 
 /// Convert the tree-sitter node at `cursor` to a difftastic syntax
@@ -1769,24 +1797,11 @@ mod tests {
         let res = parse(&arena, "<style>.a { color: red; }</style>", &config, false);
 
         match res[0] {
-            Syntax::List {
-                info: _,
-                open_position: _,
-                open_content: _,
-                children,
-                close_position: _,
-                close_content: _,
-                num_descendants: _,
-            } => {
+            Syntax::List { children, .. } => {
                 // <style>, content, </style>.
                 assert_eq!(children.len(), 3);
                 match children[1] {
-                    Syntax::Atom {
-                        info: _,
-                        position: _,
-                        content: _,
-                        kind: _,
-                    } => {
+                    Syntax::Atom { .. } => {
                         panic!("Style contents is parsed as a single atom");
                     }
                     _ => {
